@@ -1950,13 +1950,26 @@ class LayerConfiguration(ConfigurationBase):
                 md['format'] = self.context.caches[cache_name].image_opts().format
                 md['cache_name'] = cache_name
                 md['extent'] = extent
+                md['wmts_kvp_legendurl'] = self.conf.get('wmts_kvp_legendurl')
+                md['wmts_rest_legendurl'] = self.conf.get('wmts_rest_legendurl')
+                if 'legendurl' in self.conf:
+                    wms_conf = self.context.services.conf.get('wms')
+                    if wms_conf is not None:
+                        versions = wms_conf.get('versions', ['1.3.0'])
+                        versions.sort(key=lambda s: [int(u) for u in s.split('.')])
+                        legendurl = (f'{{base_url}}/service?service=WMS&amp;request=GetLegendGraphic&amp;'
+                                     f'version={versions[-1]}&amp;format=image%2Fpng&amp;layer={{layer_name}}')
+                        if md['wmts_kvp_legendurl'] is None:
+                            md['wmts_kvp_legendurl'] = legendurl
+                        if md['wmts_rest_legendurl'] is None:
+                            md['wmts_rest_legendurl'] = legendurl
                 tile_layers.append(
                     TileLayer(
                         self.conf['name'], self.conf['title'],
                         info_sources=fi_sources,
                         md=md,
                         tile_manager=cache_source,
-                        dimensions=dimensions,
+                        dimensions=dimensions
                     )
                 )
 
